==> simsu-1.3.1-1-src.tar.xz: simsu-1.3.1/translations/simsu_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="81"/>
        <location filename="../src/board.cpp" line="96"/>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor, reinicie la aplicación para que el cambio de idioma tenga efecto.</translation>
    </message>
</context>
<context>
    <name>Pattern</name>
    <message>
        <location filename="../src/pattern.h" line="78"/>
        <source>180° Rotational</source>
        <translation>180° de rotación</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="79"/>
        <source>Full Rotational</source>
        <translation>Rotación completa</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="80"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="81"/>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="82"/>
        <source>Horizontal &amp; Vertical</source>
        <translation>Horizontal &amp; Vertical</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="83"/>
        <source>Diagonal</source>
        <translation>Diagonal</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="84"/>
        <source>Anti-Diagonal</source>
        <translation>Anti-Diagonal</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="85"/>
        <source>Diagonal &amp; Anti-Diagonal</source>
        <translation>Diagonal &amp; Anti-Diagonal</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="86"/>
        <source>Full Dihedral</source>
        <translation>Diedro completo</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="87"/>
        <source>Random</source>
        <translation>Al azar</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="88"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/main.cpp" line="37"/>
        <location filename="../src/window.cpp" line="319"/>
        <source>Simsu</source>
        <translation>Simsu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="104"/>
        <source>Pen</source>
        <translation>Pluma</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="108"/>
        <source>Pencil</source>
        <translation>Lápiz</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>Highlight</source>
        <translation>Resaltado</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="114"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="121"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="158"/>
        <source>&amp;Game</source>
        <translation>&amp;Juego</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="159"/>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="160"/>
        <source>&amp;Details</source>
        <translation>&amp;Detalles</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="162"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <source>&amp;Move</source>
        <translation>&amp;Mover</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="166"/>
        <source>&amp;Undo</source>
        <translation>&amp;Deshacer</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="168"/>
        <source>&amp;Redo</source>
        <translation>&amp;Rehacer</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>&amp;Check</source>
        <translation>&amp;Comprobar</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <source>&amp;Auto Switch Modes</source>
        <translation>&amp;Modos de cambio automático</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="178"/>
        <source>&amp;Widescreen Layout</source>
        <translation>&amp;Pantalla ancha</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="183"/>
        <source>Application &amp;Language...</source>
        <translation>Aplicación &amp;Lenguaje ...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="185"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="186"/>
        <source>&amp;Controls</source>
        <translation>&amp;Controles</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="189"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="191"/>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="233"/>
        <source>New Game</source>
        <translation>Nuevo Juego</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="250"/>
        <location filename="../src/window.cpp" line="291"/>
        <source>Dancing Links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="251"/>
        <location filename="../src/window.cpp" line="291"/>
        <source>Slice and Dice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="256"/>
        <source>Random</source>
        <translation>Al azar</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="264"/>
        <source>Symmetry:</source>
        <translation>Simetría:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="265"/>
        <source>Algorithm:</source>
        <translation>Algoritmo:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="266"/>
        <source>Seed:</source>
        <translation>Semilla:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="294"/>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="294"/>
        <source>&lt;p&gt;&lt;b&gt;Symmetry:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;Simetría:&lt;/b&gt;
%1&lt;br&gt;&lt;b&gt;Algoritmo:&lt;/b&gt;
%L2&lt;br&gt;&lt;b&gt;Semilla:&lt;/ b&gt;%L3&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="303"/>
        <source>Controls</source>
        <translation>Controles</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="303"/>
        <source>&lt;p&gt;&lt;big&gt;&lt;b&gt;Mouse Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Left click:&lt;/b&gt; Toggle number in pen mode&lt;br&gt;&lt;b&gt;Right click:&lt;/b&gt; Toggle number in pencil mode&lt;br&gt;&lt;b&gt;Scrollwheel:&lt;/b&gt; Change current number&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Keyboard Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Arrow keys:&lt;/b&gt; Move selection&lt;br&gt;&lt;b&gt;Number keys:&lt;/b&gt; Toggle value or note&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Switch between pen and pencil modes&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Highlight all instances of current number&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="318"/>
        <source>About Simsu</source>
        <translation>Acerca de Simsu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="320"/>
        <source>A basic Sudoku game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="321"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="322"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado con licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> simsu-1.3.3-1-src.tar.xz: simsu-1.3.3/translations/simsu_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor, reinicie la aplicación para que el cambio de idioma tenga efecto.</translation>
    </message>
</context>
<context>
    <name>Pattern</name>
    <message>
        <source>180° Rotational</source>
        <translation>180° de rotación</translation>
    </message>
    <message>
        <source>Full Rotational</source>
        <translation>Rotación completa</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>Horizontal &amp; Vertical</source>
        <translation>Horizontal &amp; Vertical</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Diagonal</translation>
    </message>
    <message>
        <source>Anti-Diagonal</source>
        <translation>Anti-Diagonal</translation>
    </message>
    <message>
        <source>Diagonal &amp; Anti-Diagonal</source>
        <translation>Diagonal &amp; Anti-Diagonal</translation>
    </message>
    <message>
        <source>Full Dihedral</source>
        <translation>Diedro completo</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Al azar</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Simsu</source>
        <translation>Simsu</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pluma</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápiz</translation>
    </message>
    <message>
        <source>Highlight</source>
        <translation>Resaltado</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Juego</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalles</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Mover</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Deshacer</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Rehacer</translation>
    </message>
    <message>
        <source>&amp;Check</source>
        <translation>&amp;Comprobar</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>&amp;Auto Switch Modes</source>
        <translation>&amp;Modos de cambio automático</translation>
    </message>
    <message>
        <source>&amp;Widescreen Layout</source>
        <translation>&amp;Pantalla ancha</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Aplicación &amp;Lenguaje ...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controles</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nuevo Juego</translation>
    </message>
    <message>
        <source>Dancing Links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slice and Dice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Al azar</translation>
    </message>
    <message>
        <source>Symmetry:</source>
        <translation>Simetría:</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmo:</translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation>Semilla:</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Symmetry:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;Simetría:&lt;/b&gt;
%1&lt;br&gt;&lt;b&gt;Algoritmo:&lt;/b&gt;
%L2&lt;br&gt;&lt;b&gt;Semilla:&lt;/ b&gt;%L3&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controles</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;big&gt;&lt;b&gt;Mouse Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Left click:&lt;/b&gt; Toggle number in pen mode&lt;br&gt;&lt;b&gt;Right click:&lt;/b&gt; Toggle number in pencil mode&lt;br&gt;&lt;b&gt;Scrollwheel:&lt;/b&gt; Change current number&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Keyboard Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Arrow keys:&lt;/b&gt; Move selection&lt;br&gt;&lt;b&gt;Number keys:&lt;/b&gt; Toggle value or note&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Switch between pen and pencil modes&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Highlight all instances of current number&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;big&gt;&lt;b&gt;Controles del ratón:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Clic izquierdo:&lt;/b&gt; Alternar números en modo pluma&lt;br&gt;&lt;b&gt;Clic derecho:&lt;/b&gt; Alternar números en modo lápiz&lt;br&gt;&lt;b&gt;rueda de desplazamiento:&lt;/b&gt; Cambiar número actual&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Controles del teclado:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Flechas:&lt;/b&gt; Mover selección&lt;br&gt;&lt;b&gt;Teclas numéricas:&lt;/b&gt; Cambiar valor o nota&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Alternar entre modo pluma y modo lápiz&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Resaltar las instancias del número actual&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Simsu</source>
        <translation>Acerca de Simsu</translation>
    </message>
    <message>
        <source>A basic Sudoku game</source>
        <translation>Un juego básico de Sudoku</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado con licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
